
/****************************************************************************
** Adapted from PDFviewer, originally published in the QT Quarterly:
** http://doc.trolltech.com/qq/QtQuarterly27.pdf
** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** Modified for use with prerex:
** http://www.ctan.org/tex-archive/graphics/prerex
** Copyright (C) 2009 R. D. Tennent 
** School of Computing, Queen's University, rdt@cs.queensu.ca 

** This program is free software; you can redistribute it and/or modify it
** under the terms of the GNU General Public License as published by the
** Free Software Foundation; either version 2 of the License, or (at your
** option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
** Public License for more details.
** 
** You should have received a copy of the GNU General Public License along
** with this program; if not, write to the Free Software Foundation, Inc.,
** 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
**
****************************************************************************/

#include <QtGui>
#include "window.h"

Window::Window(QWidget *parent)
    : QMainWindow(parent)
{
    setupUi(this);

    scaleFactors << 1. << 1.25 << 1.5 << 2. << 3. << 4.;

    documentWidget = new DocumentWidget();
    scrollArea->setWidget(documentWidget);
    fsw = new QFileSystemWatcher();
    sb = statusBar();
    sb->showMessage(QString("This is previewer (a prerex viewer) Version %1.   ").arg(version));
    
    connect(documentControlsAction, SIGNAL(toggled(bool)),
            controlsDockWidget, SLOT(setVisible(bool)));

    connect(pageSpinBox, SIGNAL(valueChanged(int)),
            documentWidget, SLOT(setPage(int)));
    connect(documentWidget, SIGNAL(pageChanged(int)),
            pageSpinBox, SLOT(setValue(int)));
    connect(scaleComboBox, SIGNAL(currentIndexChanged(int)),
            this, SLOT(scaleDocument(int)));

    connect(fsw, SIGNAL(fileChanged(QString)), 
            documentWidget, SLOT(reloadDocument1()));

    connect(documentWidget, SIGNAL(documentReloaded()),
            this, SLOT(reloadMessage()));
}


void Window::setPath(QString Path) {
    path = Path;
    documentWidget->setDocument(path);
    scaleComboBox->setEnabled(true);
    pageSpinBox->setEnabled(true);
    pageSpinBox->setMinimum(1);
    pageSpinBox->setMaximum(documentWidget->document()->numPages());
    pageSpinBox->setValue(1);
    fsw->addPath(path);
    sb->showMessage(path);
    versionWidget = new QLabel(QString("This is previewer (a prerex viewer), v.%1").arg(version), this);
    sb->addPermanentWidget(versionWidget);
    
}

void Window::reloadMessage(void)
{
  sb->showMessage(path + " reloaded.", 2000);
  QTimer::singleShot(2000, this, SLOT(pathMessage()));
}


void Window::pathMessage(void)
{
  sb->showMessage(path);
}

void Window::scaleDocument(int index)
{
    documentWidget->setScale(scaleFactors[index]);
}
